Examples

Kindly handbooks can be written in Gleam, TypeScript, or JavaScript, and the best examples currently live in this repository.

What to look for

These examples show a few different styles of use:

For a guided introduction, see the Quickstart guide. For the full API, see the API reference.

Search Document